==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSummaryDescriptionsChangedEventArgsDescription } from "./GridSummaryDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSummaryDescriptionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, _super);
    function GridSummaryDescriptionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("SummaryDescriptions", "Collection:ColumnSummaryDescription:ColumnSummaryDescriptionCollection:ColumnSummaryDescription");
    };
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSummaryDescriptionsChangedEventArgs", function () { return new GridSummaryDescriptionsChangedEventArgsDescription(); });
        a.z("GridSummaryDescriptionsChangedEventArgs", GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.$t = markType(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, 'GridSummaryDescriptionsChangedEventArgsDescriptionMetadata');
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSummaryDescriptionsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSummaryDescriptionsChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSummaryDescriptionsChangedEventArgsDescription } from "./GridSummaryDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSummaryDescriptionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, _super);
    function GridSummaryDescriptionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("SummaryDescriptions", "Collection:ColumnSummaryDescription:ColumnSummaryDescriptionCollection:ColumnSummaryDescription");
    };
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.b(a);
        a.ac("GridSummaryDescriptionsChangedEventArgs", function () { return new GridSummaryDescriptionsChangedEventArgsDescription(); });
        a.ab("GridSummaryDescriptionsChangedEventArgs", GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.$t = markType(GridSummaryDescriptionsChangedEventArgsDescriptionMetadata, 'GridSummaryDescriptionsChangedEventArgsDescriptionMetadata');
    GridSummaryDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSummaryDescriptionsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSummaryDescriptionsChangedEventArgsDescriptionMetadata };
